@@ -44,20 +44,18 @@
 #endif
 
 /* Decimal number made with the formula yymmvv */
-#define ECL_VERSION_NUMBER 130501
+#define ECL_VERSION_NUMBER 160000
 
 /*
  * FEATURES LINKED IN
  */
-/* Always use CLOS							*/
-#define CLOS
 
 /* Use GNU Multiple Precision library for bignums                       */
 #ifndef DPP
 #include "gmp.h"
 #endif
 
-/* Userland threads?							*/
+/* Userland threads?                                                    */
 #undef ECL_THREADS
 #ifdef ECL_THREADS
 # if defined(ECL_MS_WINDOWS_HOST)
@@ -72,11 +70,11 @@
 #undef WITH___THREAD
 #endif
 
-/* Use Boehm's garbage collector					*/
+/* Use Boehm's garbage collector                                        */
 #undef GBC_BOEHM
 #ifdef GBC_BOEHM
 # ifdef ECL_THREADS
-#   define GC_THREADS		/* For >= 7.2 */
+#   define GC_THREADS           /* For >= 7.2 */
 # endif
 # define ECL_DYNAMIC_VV
 # include "gc.h"
@@ -91,30 +89,30 @@
 #endif
 #undef ECL_LIBATOMIC_OPS_H
 
-/* Network streams							*/
+/* Network streams                                                      */
 #undef TCP
 #if defined(TCP) && defined(ECL_MS_WINDOWS_HOST)
 # define ECL_WSOCK
 #endif
 
-/* Foreign functions interface						*/
+/* Foreign functions interface                                          */
 #undef ECL_FFI
 
 /* Support for Unicode strings */
 #undef ECL_UNICODE
-/* Link in the Unicode names for all characters (takes ~0.5 Mb)		*/
+/* Link in the Unicode names for all characters (takes ~0.5 Mb)         */
 #undef ECL_UNICODE_NAMES
 
-/* Allow STREAM operations to work on arbitrary objects			*/
+/* Allow STREAM operations to work on arbitrary objects                 */
 #undef ECL_CLOS_STREAMS
 
-/* Stack grows downwards						*/
+/* Stack grows downwards                                                */
 #undef ECL_DOWN_STACK
 
 /* We have libffi and can use it                                        */
 #undef HAVE_LIBFFI
 
-/* We have non-portable implementation of FFI calls			*/
+/* We have non-portable implementation of FFI calls                     */
 /* Only used as a last resort, when libffi is missin                    */
 #ifndef HAVE_LIBFFI
 #undef ECL_DYNAMIC_FFI
@@ -123,13 +121,13 @@
 /* We use hierarchical package names, like in Allegro CL                */
 #undef ECL_RELATIVE_PACKAGE_NAMES
 
-/* Use mprotect for fast interrupt dispatch				*/
+/* Use mprotect for fast interrupt dispatch                             */
 #undef ECL_USE_MPROTECT
 #if defined(ECL_MS_WINDOWS_HOST)
 # define ECL_USE_GUARD_PAGE
 #endif
 
-/* Integer types                        				*/
+/* Integer types                                                        */
 #include <stdint.h>
 #undef ecl_uint8_t
 #undef ecl_int8_t
@@ -153,35 +151,35 @@
  * but the required headers are not present in all systems. Hence we
  * use autoconf to guess the following values.
  */
-#define ECL_INT_BITS		32
-#define ECL_LONG_BITS		64
-#define FIXNUM_BITS		64
-#define MOST_POSITIVE_FIXNUM	((cl_fixnum)2305843009213693951L)
-#define MOST_NEGATIVE_FIXNUM	((cl_fixnum)-2305843009213693952L)
-#define MOST_POSITIVE_FIXNUM_VAL 2305843009213693951L
-#define MOST_NEGATIVE_FIXNUM_VAL -2305843009213693952L
+#define ECL_INT_BITS            32
+#define ECL_LONG_BITS           32
+#define FIXNUM_BITS             32
+#define MOST_POSITIVE_FIXNUM    ((cl_fixnum)536870911)
+#define MOST_NEGATIVE_FIXNUM    ((cl_fixnum)-536870912)
+#define MOST_POSITIVE_FIXNUM_VAL 536870911
+#define MOST_NEGATIVE_FIXNUM_VAL -536870912
 
-typedef long int cl_fixnum;
-typedef unsigned long int cl_index;
-typedef unsigned long int cl_hashkey;
+typedef int cl_fixnum;
+typedef unsigned int cl_index;
+typedef unsigned int cl_hashkey;
 
 /*
  * The character type
  */
-#define	ECL_CHAR_CODE_LIMIT	1114112 /* ASCII or unicode character code limit  */
+#define ECL_CHAR_CODE_LIMIT     1114112 /* ASCII or unicode character code limit  */
 typedef int32_t ecl_character;
 typedef unsigned char ecl_base_char;
 
 /*
  * Array limits
  */
-#define	ECL_ARRAY_RANK_LIMIT 64	/*  array rank limit  		*/
+#define ECL_ARRAY_RANK_LIMIT 64 /*  array rank limit            */
 #ifdef GBC_BOEHM
-#define	ECL_ARRAY_DIMENSION_LIMIT 2305843009213693951L
-#define	ECL_ARRAY_TOTAL_LIMIT 2305843009213693951L
+#define ECL_ARRAY_DIMENSION_LIMIT 536870911
+#define ECL_ARRAY_TOTAL_LIMIT 536870911
 #else
-#define	ECL_ARRAY_DIMENSION_LIMIT 16*1024*1024
-#define	ECL_ARRAY_TOTAL_LIMIT 16*1024*1024
+#define ECL_ARRAY_DIMENSION_LIMIT 16*1024*1024
+#define ECL_ARRAY_TOTAL_LIMIT 16*1024*1024
 #endif
 
 /*
@@ -189,22 +187,22 @@ typedef unsigned char ecl_base_char;
  *
  * In general, any of these limits must fit in a "signed int".
  */
-/*	Maximum number of function arguments (arbitrary)		*/
+/*      Maximum number of function arguments (arbitrary)                */
 #define ECL_CALL_ARGUMENTS_LIMIT 65536
 
-/*	Maximum number of required arguments				*/
+/*      Maximum number of required arguments                            */
 #define ECL_LAMBDA_PARAMETERS_LIMIT ECL_CALL_ARGUMENTS_LIMIT
 
-/*	Numb. of args. which will be passed using the C stack		*/
-/*	See cmplam.lsp if you change this value				*/
+/*      Numb. of args. which will be passed using the C stack           */
+/*      See cmplam.lsp if you change this value                         */
 #define ECL_C_ARGUMENTS_LIMIT 63
 
-/*	Maximum number of output arguments (>= ECL_C_ARGUMENTS_LIMIT)	*/
+/*      Maximum number of output arguments (>= ECL_C_ARGUMENTS_LIMIT)   */
 #define ECL_MULTIPLE_VALUES_LIMIT 64
 
-/* A setjmp that does not save signals					*/
-#define ecl_setjmp	_setjmp
-#define ecl_longjmp	_longjmp
+/* A setjmp that does not save signals                                  */
+#define ecl_setjmp      _setjmp
+#define ecl_longjmp     _longjmp
 
 /*
  * Structure/Instance limits. The index to a slot must fit in the
@@ -212,7 +210,7 @@ typedef unsigned char ecl_base_char;
  * because constructors typically require as many arguments as slots,
  * or more.
  */
-#define ECL_SLOTS_LIMIT	32768
+#define ECL_SLOTS_LIMIT 32768
 
 /* compiler understands long double                                     */
 #undef ECL_LONG_FLOAT
@@ -220,10 +218,10 @@ typedef unsigned char ecl_base_char;
 #undef HAVE_DOUBLE_COMPLEX
 #undef HAVE_FLOAT_COMPLEX
 
-/* We can use small, two-words conses, without type information		*/
+/* We can use small, two-words conses, without type information         */
 #undef ECL_SMALL_CONS
 
-/* Use CMU Common-Lisp's FORMAT routine					*/
+/* Use CMU Common-Lisp's FORMAT routine                                 */
 #undef ECL_CMU_FORMAT
 
 /*
@@ -263,102 +261,105 @@ typedef unsigned char ecl_base_char;
 #undef ECL_SSE2
 #endif
 
-/* -CUT-: Everything below this mark will not be installed		*/
+/* -CUT-: Everything below this mark will not be installed              */
 /* -------------------------------------------------------------------- *
- *	BUILD OPTIONS WHICH NEED NOT BE EXPORTED			*
+ *      BUILD OPTIONS WHICH NEED NOT BE EXPORTED                        *
  * -------------------------------------------------------------------- */
 /*
  * FEATURES LINKED IN:
  */
 
-/* CLX									*/
+/* CLX                                                                  */
 #undef CLX
-/* Locatives								*/
+/* Locatives                                                            */
 #undef LOCATIVE
-/* Use old MIT LOOP macro system					*/
+/* Use old MIT LOOP macro system                                        */
 #undef ECL_OLD_LOOP
 
-/* Define this if you want a runtime version only without compiler	*/
+/* Define this if you want a runtime version only without compiler      */
 #undef RUNTIME
-/* Profile tool								*/
+/* Profile tool                                                         */
 #undef PROFILE
-/* Program Development Environment					*/
+/* Program Development Environment                                      */
 #undef PDE
 
-/* Allow loading dynamically linked code				*/
+/* Allow loading dynamically linked code                                */
 #undef ENABLE_DLOPEN
 
-/* Undefine this if you do not want ECL to check for circular lists	*/
+/* Undefine this if you do not want ECL to check for circular lists     */
 #define ECL_SAFE
 
-/* Bytecodes and arguments are 8 and 16 bits large, respectively	*/
+/* Bytecodes and arguments are 8 and 16 bits large, respectively        */
 #undef ECL_SMALL_BYTECODES
 
-/* Assembler implementation of APPLY and friends			*/
+/* Assembler implementation of APPLY and friends                        */
 #undef ECL_ASM_APPLY
 
-/* Activate Boehm-Weiser incremental garbage collector			*/
+/* Activate Boehm-Weiser incremental garbage collector                  */
 #undef GBC_BOEHM_GENGC
 
-/* Activate Boehm-Weiser precise garbage collector			*/
+/* Activate Boehm-Weiser precise garbage collector                      */
 #undef GBC_BOEHM_PRECISE
 
-/* Weak hash tables need the garbage collector and weak	pointers	*/
+/* Weak hash tables need the garbage collector and weak pointers        */
 #ifdef GBC_BOEHM
 #define ECL_WEAK_HASH
 #endif
 
+/* GC_set_start_callback                                                */
+#undef HAVE_GC_SET_START_CALLBACK
+
 /*
  * SYSTEM FEATURES:
  */
 
-/* Argument list can be access as an array				*/
+/* Argument list can be access as an array                              */
 #undef ECL_USE_VARARG_AS_POINTER
-/* Most significant byte first						*/
+/* Most significant byte first                                          */
 #undef WORDS_BIGENDIAN
-/* Has <sys/resource.h>							*/
+/* Has <sys/resource.h>                                                 */
 #undef HAVE_SYS_RESOURCE_H
 #undef HAVE_ULIMIT_H
-/* High precision timer							*/
+/* High precision timer                                                 */
 #undef HAVE_NANOSLEEP
-/* Float version if isnan()						*/
+/* Float version if isnan()                                             */
 #undef HAVE_ISNANF
-/* float.h for epsilons, maximum real numbers, etc			*/
+/* float.h for epsilons, maximum real numbers, etc                      */
 #undef HAVE_FLOAT_H
-/* select()								*/
+/* select()                                                             */
 #undef HAVE_SELECT
 #undef HAVE_SYS_SELECT_H
 #undef HAVE_SYS_IOCTL_H
-/* putenv() or setenv()							*/
+/* putenv() or setenv()                                                 */
 #undef HAVE_SETENV
 #undef HAVE_PUTENV
-/* times() and sys/times.h						*/
+/* times() and sys/times.h                                              */
 #undef HAVE_TIMES
-/* gettimeofday() and sys/time.h					*/
+/* gettimeofday() and sys/time.h                                        */
 #undef HAVE_GETTIMEOFDAY
-/* getrusage() and sys/resource.h					*/
+/* getrusage() and sys/resource.h                                       */
 #undef HAVE_GETRUSAGE
-/* user home directory, user name, etc...				*/
+/* user home directory, user name, etc...                               */
 #undef HAVE_PW_H
-/* symbolic links and checking their existence				*/
+/* symbolic links and checking their existence                          */
 #undef HAVE_LSTAT
-/* safe creation of temporary files					*/
+/* safe creation of temporary files                                     */
 #undef HAVE_MKSTEMP
-/* timer for userland threads						*/
+/* timer for userland threads                                           */
 #undef HAVE_ALARM
-/* filesytem								*/
+/* filesytem                                                            */
 #undef HAVE_DIRENT_H
-/* dynamic linking of libraries						*/
+/* dynamic linking of libraries                                         */
 #undef HAVE_DLFCN_H
 #undef HAVE_LINK_H
 #undef HAVE_MACH_O_DYLD_H
-/* POSIX signals							*/
+/* POSIX signals                                                        */
 #undef HAVE_SIGPROCMASK
-/* isatty() checks whether a file is connected to a			*/
+/* isatty() checks whether a file is connected to a                     */
 #undef HAVE_ISATTY
-/* can manipulate floating point environment				*/
+/* can manipulate floating point environment                            */
 #undef HAVE_FENV_H
-/* can activate individual traps in floating point environment		*/
+/* can activate individual traps in floating point environment          */
 /* this flag has to be deactivated for the Itanium architecture, where  */
 /* the GNU libc functions are broken                                    */
 #if !defined(__ia64__) && !defined(PPC)
@@ -366,15 +367,15 @@ typedef unsigned char ecl_base_char;
 #endif
 /* do we want to deactivate all support for floating point exceptions   */
 #undef ECL_AVOID_FPE_H
-/* do we want to have signed zeros					*/
+/* do we want to have signed zeros                                      */
 #undef ECL_SIGNED_ZERO
-/* do we want NaNs and Infs						*/
+/* do we want NaNs and Infs                                             */
 #undef ECL_IEEE_FP
-/* has support for large files						*/
+/* has support for large files                                          */
 #undef HAVE_FSEEKO
-/* the tzset() function gets the current time zone			*/
+/* the tzset() function gets the current time zone                      */
 #undef HAVE_TZSET
-/* several floating point functions (ISO C99)				*/
+/* several floating point functions (ISO C99)                           */
 #if 0
 #undef HAVE_EXPF
 #undef HAVE_LOGF
@@ -397,20 +398,20 @@ typedef unsigned char ecl_base_char;
 #undef HAVE_COPYSIGNF
 #undef HAVE_COPYSIGN
 #undef HAVE_COPYSIGNL
-/* whether we have sched_yield() that gives priority to other threads	*/
+/* whether we have sched_yield() that gives priority to other threads   */
 #undef HAVE_SCHED_YIELD
 /* whether we have a working sem_init()                                 */
 #undef HAVE_SEM_INIT
 /* whether we have read/write locks                                     */
 #undef HAVE_POSIX_RWLOCK
-/* uname() for system identification					*/
+/* uname() for system identification                                    */
 #undef HAVE_UNAME
 #undef HAVE_UNISTD_H
 #undef HAVE_SYS_WAIT_H
 #undef HAVE_SYS_MMAN_H
-/* size of long long            					*/
+/* size of long long                                                    */
 #undef ECL_LONG_LONG_BITS
-/* existence of char **environ         					*/
+/* existence of char **environ                                          */
 #undef HAVE_ENVIRON
 /* existence of pointer -> function name functions                      */
 #undef HAVE_DLADDR
@@ -432,7 +433,7 @@ typedef unsigned char ecl_base_char;
 # endif
 #endif
 
-/* what characters are used to mark beginning of new line		*/
+/* what characters are used to mark beginning of new line               */
 #undef ECL_NEWLINE_IS_CRLF
 #undef ECL_NEWLINE_IS_LFCR
 
@@ -443,44 +444,44 @@ typedef unsigned char ecl_base_char;
 /*
  * Memory limits for the old garbage collector.
  */
-#define	LISP_PAGESIZE	2048	/* Page size in bytes			*/
-#define MAXPAGE	65536		/* Maximum Memory Size			*/
+#define LISP_PAGESIZE   2048    /* Page size in bytes                   */
+#define MAXPAGE 65536           /* Maximum Memory Size                  */
 
 /* We allocate a number of strings in a pool which is used to speed up reading */
-#define ECL_MAX_STRING_POOL_SIZE	10
-#define ECL_BUFFER_STRING_SIZE		4192
+#define ECL_MAX_STRING_POOL_SIZE        10
+#define ECL_BUFFER_STRING_SIZE          4192
 
 /*
  * Macros that depend on these system features.
  */
 #if defined(sparc) || defined(i386) || defined(mips)
-#  define	stack_align(n)	(((n) + 0x7) & ~0x7)
+#  define       stack_align(n)  (((n) + 0x7) & ~0x7)
 #else
-#  define	stack_align(n)	(((n) + 03) & ~03)
+#  define       stack_align(n)  (((n) + 03) & ~03)
 #endif
 
 #undef FILE_CNT
 #if 2 == 1
-#  define FILE_CNT(fp)	((fp)->_IO_read_end - (fp)->_IO_read_ptr)
+#  define FILE_CNT(fp)  ((fp)->_IO_read_end - (fp)->_IO_read_ptr)
 #endif
 #if 2 == 2
-#  define FILE_CNT(fp)	((fp)->_r)
+#  define FILE_CNT(fp)  ((fp)->_r)
 #endif
 #if 2 == 3
-#  define FILE_CNT(fp)	((fp)->_cnt)
+#  define FILE_CNT(fp)  ((fp)->_cnt)
 #endif
 
 #if defined(cygwin) || defined(ECL_MS_WINDOWS_HOST)
 #  define IS_DIR_SEPARATOR(x) ((x=='/')||(x=='\\'))
-#  define DIR_SEPARATOR		'/'
-#  define PATH_SEPARATOR	';'
+#  define DIR_SEPARATOR         '/'
+#  define PATH_SEPARATOR        ';'
 #else
 #  define IS_DIR_SEPARATOR(x) (x=='/')
-#  define DIR_SEPARATOR	'/'
-#  define PATH_SEPARATOR	':'
+#  define DIR_SEPARATOR '/'
+#  define PATH_SEPARATOR        ':'
 #endif
 
-#define ECL_ARCHITECTURE "SPARC64"
+#define ECL_ARCHITECTURE "HPPA"
 
 #ifdef ECL_AVOID_FPE_H
 # define ecl_detect_fpe()
